==> jbake-core-2.6.3-sources.jar: org/jbake/parser/ParserContext.java <==
package org.jbake.parser;

import org.jbake.app.Crawler;
import org.jbake.app.configuration.JBakeConfiguration;

import java.io.File;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class ParserContext {
    private final File file;
    private final List<String> fileLines;
    private final JBakeConfiguration config;
    private final boolean hasHeader;
    private final Map<String,Object> documentModel;

    public ParserContext(
            File file,
            List<String> fileLines,
            JBakeConfiguration config,
            boolean hasHeader) {
        this.file = file;
        this.fileLines = fileLines;
        this.config = config;
        this.hasHeader = hasHeader;
        this.documentModel = new HashMap<>();
    }

    public File getFile() {
        return file;
    }

    public List<String> getFileLines() {
        return fileLines;
    }

    public JBakeConfiguration getConfig() {
        return config;
    }

    public Map<String, Object> getDocumentModel() {
        return documentModel;
    }

    public boolean hasHeader() {
        return hasHeader;
    }

    // short methods for common use
    public String getBody() {
        return documentModel.get(Crawler.Attributes.BODY).toString();
    }

    public void setBody(String str) {
        documentModel.put(Crawler.Attributes.BODY, str);
    }

    public Object getDate() {
        return getDocumentModel().get(Crawler.Attributes.DATE);
    }

    public void setDate(Date date) {
        getDocumentModel().put(Crawler.Attributes.DATE, date);
    }

    public String getStatus() {
        if (getDocumentModel().containsKey(Crawler.Attributes.STATUS)) {
            return getDocumentModel().get(Crawler.Attributes.STATUS).toString();
        }
        return "";
    }

    public void setDefaultStatus() {
        getDocumentModel().put(Crawler.Attributes.STATUS, getConfig().getDefaultStatus());
    }

    public String getType() {
        if (getDocumentModel().containsKey(Crawler.Attributes.TYPE)) {
            return getDocumentModel().get(Crawler.Attributes.TYPE).toString();
        }
        return "";
    }

    public void setDefaultType() {
        getDocumentModel().put(Crawler.Attributes.TYPE, getConfig().getDefaultType());
    }

    public Object getTags() {
        return getDocumentModel().get(Crawler.Attributes.TAGS);
    }

    public void setTags(String[] tags) {
        getDocumentModel().put(Crawler.Attributes.TAGS, tags);
    }
}

==> jbake-core-2.7.0-rc.1-sources.jar: org/jbake/parser/ParserContext.java <==
package org.jbake.parser;

import org.jbake.app.configuration.JBakeConfiguration;
import org.jbake.model.DocumentModel;

import java.io.File;
import java.util.Date;
import java.util.List;

public class ParserContext {
    private final File file;
    private final List<String> fileLines;
    private final JBakeConfiguration config;
    private final boolean hasHeader;
    private final DocumentModel documentModel;

    public ParserContext(
            File file,
            List<String> fileLines,
            JBakeConfiguration config,
            boolean hasHeader) {
        this.file = file;
        this.fileLines = fileLines;
        this.config = config;
        this.hasHeader = hasHeader;
        this.documentModel = DocumentModel.createDefaultDocumentModel();
    }

    public File getFile() {
        return file;
    }

    public List<String> getFileLines() {
        return fileLines;
    }

    public JBakeConfiguration getConfig() {
        return config;
    }

    public DocumentModel getDocumentModel() {
        return documentModel;
    }

    public boolean hasHeader() {
        return hasHeader;
    }

    // short methods for common use
    public String getBody() {
        return documentModel.getBody();
    }

    public void setBody(String str) {
        documentModel.setBody(str);
    }

    public Date getDate() {
        return getDocumentModel().getDate();
    }

    public void setDate(Date date) {
        getDocumentModel().setDate(date);
    }

    public String getStatus() {
        if (getDocumentModel().getStatus() != null) {
            return getDocumentModel().getStatus();
        }
        return "";
    }

    public void setDefaultStatus() {
        getDocumentModel().setStatus(getConfig().getDefaultStatus());
    }

    public String getType() {
        if (getDocumentModel().getType() != null) {
            return getDocumentModel().getType();
        }
        return "";
    }

    public void setDefaultType() {
        getDocumentModel().setType(getConfig().getDefaultType());
    }

    public Object getTags() {
        return getDocumentModel().getTags();
    }

    public void setTags(String[] tags) {
        getDocumentModel().setTags(tags);
    }
}
